=====================
Abaqus Model Database
=====================

.. toctree::
   :maxdepth: 1
   :caption: Objects in mdb

   mdb/model
   mdb/job

.. autoclass:: abaqus.Mdb.Mdb.Mdb
   :noindex:

   .. autoclasstoc::

.. This is a comment ro supress the warning "(ERROR/3) Document may not end with a transition."
